==> git-1.1.17-sources.jar: hudson/plugins/git/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.git;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * No new revisions were found; the most-recently built branch will be built again.
     * 
     */
    public static String BuildChooser_BuildingLastRevision() {
        return holder.format("BuildChooser_BuildingLastRevision");
    }

    /**
     * No new revisions were found; the most-recently built branch will be built again.
     * 
     */
    public static Localizable _BuildChooser_BuildingLastRevision() {
        return new Localizable(holder, "BuildChooser_BuildingLastRevision");
    }

    /**
     * Inverse
     * 
     */
    public static String BuildChooser_Inverse() {
        return holder.format("BuildChooser_Inverse");
    }

    /**
     * Inverse
     * 
     */
    public static Localizable _BuildChooser_Inverse() {
        return new Localizable(holder, "BuildChooser_Inverse");
    }

    /**
     * All current git branches were excluded from being built. Either your branch specifiers are too broad or you should be using the "Default" choosing strategy.
     * 
     */
    public static String BuildChooser_Inverse_EverythingExcluded() {
        return holder.format("BuildChooser_Inverse_EverythingExcluded");
    }

    /**
     * All current git branches were excluded from being built. Either your branch specifiers are too broad or you should be using the "Default" choosing strategy.
     * 
     */
    public static Localizable _BuildChooser_Inverse_EverythingExcluded() {
        return new Localizable(holder, "BuildChooser_Inverse_EverythingExcluded");
    }

    /**
     * Default
     * 
     */
    public static String BuildChooser_Default() {
        return holder.format("BuildChooser_Default");
    }

    /**
     * Default
     * 
     */
    public static Localizable _BuildChooser_Default() {
        return new Localizable(holder, "BuildChooser_Default");
    }

}

==> git-2.2.10-sources.jar: hudson/plugins/git/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.git;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * No new revisions were found; the most-recently built branch will be built again.
     * 
     */
    public static String BuildChooser_BuildingLastRevision() {
        return holder.format("BuildChooser_BuildingLastRevision");
    }

    /**
     * No new revisions were found; the most-recently built branch will be built again.
     * 
     */
    public static Localizable _BuildChooser_BuildingLastRevision() {
        return new Localizable(holder, "BuildChooser_BuildingLastRevision");
    }

    /**
     * Failed to connect to repository : {0}
     * 
     */
    public static String UserRemoteConfig_FailedToConnect(Object arg1) {
        return holder.format("UserRemoteConfig.FailedToConnect", arg1);
    }

    /**
     * Failed to connect to repository : {0}
     * 
     */
    public static Localizable _UserRemoteConfig_FailedToConnect(Object arg1) {
        return new Localizable(holder, "UserRemoteConfig.FailedToConnect", arg1);
    }

    /**
     * Inverse
     * 
     */
    public static String BuildChooser_Inverse() {
        return holder.format("BuildChooser_Inverse");
    }

    /**
     * Inverse
     * 
     */
    public static Localizable _BuildChooser_Inverse() {
        return new Localizable(holder, "BuildChooser_Inverse");
    }

    /**
     * All current git branches were excluded from being built. Either your branch specifiers are too broad or you should be using the "Default" choosing strategy.
     * 
     */
    public static String BuildChooser_Inverse_EverythingExcluded() {
        return holder.format("BuildChooser_Inverse_EverythingExcluded");
    }

    /**
     * All current git branches were excluded from being built. Either your branch specifiers are too broad or you should be using the "Default" choosing strategy.
     * 
     */
    public static Localizable _BuildChooser_Inverse_EverythingExcluded() {
        return new Localizable(holder, "BuildChooser_Inverse_EverythingExcluded");
    }

    /**
     * Default
     * 
     */
    public static String BuildChooser_Default() {
        return holder.format("BuildChooser_Default");
    }

    /**
     * Default
     * 
     */
    public static Localizable _BuildChooser_Default() {
        return new Localizable(holder, "BuildChooser_Default");
    }

}
